@@ -5,11 +5,11 @@
 (defparameter *autoconf-prefix* "/usr/local")
 (defparameter *autoconf-exec_prefix* "/usr/local")
 (defparameter *autoconf-package* "maxima")
-(defparameter *autoconf-version* "5.22.1")
+(defparameter *autoconf-version* "5.23.2")
 (defparameter *autoconf-libdir* "/usr/local/lib")
 (defparameter *autoconf-libexecdir* "/usr/local/libexec")
 (defparameter *autoconf-datadir* "/usr/local/share")
-(defparameter *autoconf-infodir* "/usr/local/info")
+(defparameter *autoconf-infodir* "/usr/local/share/info")
 (defparameter *autoconf-host* "i686-pc-linux-gnu")
 (defparameter *autoconf-win32* "false")
 (defparameter *autoconf-ld-flags* "")
