@@ -316,7 +316,7 @@ One extra decimal digit in actual representation for rounding purposes.")
   (if (float-inf-p x)
     (merror (intl:gettext "bfloat: attempted conversion of floating-point infinity.~%")))
   (unless $float2bf
-    (mtell (intl:gettext "bfloat: converting float ~S to bigfloat.") x))
+    (mtell (intl:gettext "bfloat: converting float ~S to bigfloat.~%") x))
 
   ;; Need to check for zero because different lisps return different
   ;; values for integer-decode-float of a 0.  In particular CMUCL
@@ -532,7 +532,7 @@ One extra decimal digit in actual representation for rounding purposes.")
 	    ;;    acot(z) = atan(1/z)
 	    (setq tmp (fpquotient (fppi) two))
 	    (setq ans (fpdifference tmp (fpatan (fpquotient one x))))
-	    (return (cond ((fpgreaterp ans tmp)
+	    (return (cond ((fplessp x (intofp 0))
 			   (fpdifference ans (fppi)))
 			  (t ans))))
 	   ((fpgreaterp (fpabs x) (fpquotient one two))
@@ -858,7 +858,7 @@ One extra decimal digit in actual representation for rounding purposes.")
        (setq n (do ((j (- k 2) (1- j)) (p 1))
 		   ((< j 0) p)
 		 (setq p (1+ (* p (- i j))))) )
-       (setq h (*quo (* h n) d))
+       (setq h (truncate (* h n) d))
        (setq s (+ s h)))
      s))
 ;;................................................................................ Volker van Nek 2007 .. ;;
@@ -886,13 +886,13 @@ One extra decimal digit in actual representation for rounding purposes.")
 (defun comppi (prec)
   (let (s h n d)
      (setq s (ash 13591409 prec))
-     (setq h (neg (*quo (ash 67047785160 prec) 262537412640768000)))
+     (setq h (neg (truncate (ash 67047785160 prec) 262537412640768000)))
      (setq s (+ s h))
      (do ((i 2 (1+ i)))
 	 ((zerop h))
        (setq n (* 12 (- (* 6 i) 5) (- (* 6 i) 4) (- (* 2 i) 1) (- (* 6 i) 1) (+ (* i 545140134) 13591409) ))
        (setq d (* (- (* 3 i) 2) (expt i 3) (- (* i 545140134) 531548725) 262537412640768000))
-       (setq h (neg (*quo (* h n) d)))
+       (setq h (neg (truncate (* h n) d)))
        (setq s (+ s h)))
      s ))
 ;;
