@@ -1,3 +1,5 @@
+;;; -*-  Mode: Lisp; Package: Maxima; Syntax: Common-Lisp; Base: 10 -*- ;;;;
+
 (in-package :maxima)
 
 ;; TeX-printing
@@ -657,8 +659,11 @@
   (let ((op (cond ((eq (caar x) '%lsum) "\\sum_{")
 		  ;; extend here
 		  ))
-	;; gotta be one of those above 
-	(s1 (tex (cadr x) nil nil 'mparen rop))	;; summand
+	;; gotta be one of those above
+	;; 4th arg of tex is changed from mparen to (caar x)
+	;; to reflect the operator preceedance correctly.
+	;; This change improves the how to put paren.
+	(s1 (tex (cadr x) nil nil (caar x) rop))	;; summand
 	(index ;; "index = lowerlimit"
 	 (tex `((min simp) , (caddr x), (cadddr x))  nil nil 'mparen 'mparen)))
     (append l `( ,op ,@index "}}{" ,@s1 "}") r)))
@@ -669,7 +674,10 @@
 		  ;; extend here
 		  ))
 	;; gotta be one of those above
-	(s1 (tex (cadr x) nil nil 'mparen rop))	;; summand
+	;; 4th arg of tex is changed from mparen to (caar x)
+	;; to reflect the operator preceedance correctly.
+	;; This change improves the how to put paren.
+	(s1 (tex (cadr x) nil nil (caar x) rop))	;; summand
 	(index ;; "index = lowerlimit"
 	 (tex `((mequal simp) ,(caddr x),(cadddr x)) nil nil 'mparen 'mparen))
 	(toplim (tex (car(cddddr x)) nil nil 'mparen 'mparen)))
@@ -931,14 +939,51 @@
 	((= c 1)(cons (car n)(odds (cdr n) 0)))
 	((= c 0)(odds (cdr n) 1))))
 
+;;
+;; The format of MCOND expressions is documented above the definition
+;; of DIM-MCOND in displa.lisp.  Here are some examples:
+;;
+;;   ((%mcond) $a $b t nil)         <==>  'if a then b
+;;   ((%mcond) $a $b t $d)          <==>  'if a then b else d
+;;   ((%mcond) $a $b $c nil t nil)  <==>  'if a then b elseif c then false
+;;   ((%mcond) $a $b $c $d t nil)   <==>  'if a then b elseif c then d
+;;   ((%mcond) $a $b $c $d t $f)    <==>  'if a then b elseif c then d else f
+;; 
+;; Note that DIM-MCOND omits display of the final "else" in three
+;; cases illustrated below, so we do the same here:
+;; 
+;;   ((%mcond) $a $b $c $d t $false)  <==>  '(if a then b elseif c then d)
+;;   ((%mcond) $a $b $c $d t nil)     <==>   'if a then b elseif c then d
+;;   ((%mcond) $a $b $c $d)            ==>   'if a then b elseif c then d
+;;
+;; The first two cases occur in practice, as can be seen by evaluating
+;; ?print('(if a then b)) and ?print(if a then b).  The parser
+;; produces the first case, which is transformed into the second case
+;; during evaluation.  The third case is handled equivalently by the
+;; evaluator and DIM-MCOND, and might plausibly be created by some
+;; code, so we handle it here as well.
+;;
+;; The use of '$false (instead of nil) may be a hack that is no longer
+;; needed.  For more information on this, search for $false in
+;; PARSE-CONDITION of nparse.lisp and DIM-MCOND of displa.lisp.  Also
+;; see the mailing list thread with subject "Bugs in tex-mcond" which
+;; took place in January 2011.  -MHW
+;;
 (defun tex-mcond (x l r)
-  (append l
-	  (tex (cadr x) '("\\mathbf{if}\\;")
-	       '("\\;\\mathbf{then}\\;") 'mparen 'mparen)
-	  (if (eql (fifth x) '$false)
-	      (tex (caddr x) nil r 'mcond rop)
-	      (append (tex (caddr x) nil nil 'mparen 'mparen)
-		      (tex (fifth x) '("\\;\\mathbf{else}\\;") r 'mcond rop)))))
+  (labels
+      ((recurse (x l)
+	 (append
+	  (tex (car x) l '("\\;\\mathbf{then}\\;") 'mparen 'mparen)
+	  (cond ((member (cddr x) '(() (t nil) (t $false)) :test #'equal)
+		 (tex (second x) nil r 'mcond rop))
+		((and (eq (third x) t) (null (nthcdr 4 x)))
+		 (append
+		  (tex (second x) nil nil 'mparen 'mparen)
+		  (tex (fourth x) '("\\;\\mathbf{else}\\;") r 'mcond rop)))
+		(t (append
+		    (tex (second x) nil nil 'mparen 'mparen)
+		    (recurse (cddr x) '("\\;\\mathbf{elseif}\\;"))))))))
+  (append l (recurse (cdr x) '("\\mathbf{if}\\;")))))
 
 (defprop mdo tex-mdo tex)
 (defprop mdoin tex-mdoin tex)
@@ -1040,7 +1085,7 @@
                       (list
                         (let ((f-x (mfuncall ',f x)))
                           (if (stringp f-x) f-x
-                            (merror "tex: function ~s did not return a string.~%" ($sconcat ',f)))))
+                            (merror (intl:gettext "tex: function ~s did not return a string.~%") ($sconcat ',f)))))
                       r)))
     (setf (symbol-function glue-f) (coerce `(lambda (x l r) ,f-body) 'function))
     (setf (get op 'tex) glue-f))
@@ -1068,7 +1113,7 @@
     ((stringp e)
      (setq e ($verbify e)))
     ((not (symbolp e))
-     (merror "texput: first argument must be a string or a symbol.")))
+     (merror (intl:gettext "texput: first argument must be a string or a symbol; found: ~M") e)))
 
   (setq s (if ($listp s) (margs s) (list s)))
   
@@ -1085,7 +1130,7 @@
 	((eq tx '$matchfix)
 	 (putprop e 'tex-matchfix 'tex)
 	 (cond ((< (length s) 2)
-		(merror "Improper 2nd argument to `texput' for matchfix operator."))
+		(merror (intl:gettext "texput: expected a list of two items for matchfix operator.")))
 	       ((= (length s) 2)
 		(putprop e (list (list (first s)) (second s)) 'texsym))
 	       (t
