@@ -34,7 +34,7 @@ sin(y)*(10.0+6*cos(x)),
 (defmfun $join (x y)
   (if (and ($listp x) ($listp y))
       (cons '(mlist) (loop for w in (cdr x) for u in (cdr y) collect w collect u))
-      (merror "Both arguments to 'join' must be lists")))
+      (merror (intl:gettext "join: both arguments must be lists."))))
 
 (defun coerce-float (x) ($float (meval* x)))
 
@@ -78,7 +78,7 @@ sin(y)*(10.0+6*cos(x)),
     ;; adaptive-plotting will do.
     ((mlist) $adapt_depth 5)
     ((mlist) $gnuplot_preamble "")
-    ((mlist) $gnuplot_default_term_command "set term pop")
+    ((mlist) $gnuplot_default_term_command ,(if (string= *autoconf-win32* "true") "set term windows" "set term pop"))
     ((mlist) $gnuplot_dumb_term_command
      "set term dumb 79 22")
     ((mlist) $gnuplot_ps_term_command
@@ -129,7 +129,7 @@ sin(y)*(10.0+6*cos(x)),
                                 :wait nil :output nil
                                 :input :stream)))
   #-(or clisp cmu sbcl gcl scl lispworks ecl ccl)
-  (merror "Gnuplot not supported with your lisp!")
+  (merror (intl:gettext "plotting: I don't know how to tell this Lisp to run Gnuplot."))
   
   ;; set mouse must be the first command send to gnuplot
   (send-gnuplot-command "set mouse"))
@@ -180,14 +180,14 @@ sin(y)*(10.0+6*cos(x)),
 
 (defun $gnuplot_replot (&optional s)
   (if (null *gnuplot-stream*)
-      (merror "Gnuplot is not running."))
+      (merror (intl:gettext "gnuplot_replot: Gnuplot is not running.")))
   (cond ((null s)
          (send-gnuplot-command "replot"))
         ((stringp s)
          (send-gnuplot-command s)
          (send-gnuplot-command "replot"))
         (t
-         (merror "Input to 'gnuplot_replot' is not a string!")))
+         (merror (intl:gettext "gnuplot_replot: argument, if present, must be a string; found: ~M") s)))
   "")
 
 ;; allow this to be set in a system init file (sys-init.lsp)
@@ -206,13 +206,13 @@ sin(y)*(10.0+6*cos(x)),
 
 (defun check-list-items (name lis type length)
   (or (eql (length lis) length)
-      (merror "~M items were expected in the ~M list" length name))
+      (merror (intl:gettext "set_plot_option: expected ~M items in the ~M list; found ~M items.") length name (length lis)))
   `((mlist) , name ,@
     (loop for v in lis
      do (setq v (meval* v))
      when (not (typep v type))
      do
-     (merror "~M is not of the right type in ~M list" v name)
+     (merror (intl:gettext "set_plot_option: expected only ~M items in the ~M list; found a ~M.") type name (type-of v))
      collect v)))
 
 (defun $set_plot_option ( value)
@@ -220,7 +220,7 @@ sin(y)*(10.0+6*cos(x)),
   (unless (and ($listp value) (symbolp (setq name (second value))))
     (merror
      (intl:gettext
-      "set_plot_option: ~M is not a plot option. Must be [symbol,..data]")
+      "set_plot_option: plot option must be a list whose first element is a symbol; found: ~M")
      value))
   (setq value
         (case name
@@ -234,7 +234,7 @@ sin(y)*(10.0+6*cos(x)),
           ($axes
            (unless (member (third value) '($x $y t nil))
              (merror
-              (intl:gettext "axes: must be either true, false, x or y")))
+              (intl:gettext "set_plot_option: axes must be either true, false, x or y; found: ~M") (third value)))
            value)
           ($plot_format
            (case (third value) ($openmath (setf (third value) '$xmaxima)))
@@ -245,20 +245,20 @@ sin(y)*(10.0+6*cos(x)),
                              $mgnuplot $xmaxima)))
              (merror
               (intl:gettext
-               "plot_format: only gnuplot, mgnuplot, xmaxima, and geomview are recognized")))
+               "set_plot_option: plot_format must be either gnuplot, mgnuplot, xmaxima, or geomview; found: ~M") (third value)))
            value)
           (($color $point_type $palette) value)
           (($azimuth $elevation)
            (unless (integerp (third value))
-             (merror (intl:gettext "azimuth: must be an integer")))
+             (merror (intl:gettext "set_plot_option: azimuth must be an integer; found: ~M") (third value)))
            value)
           ($mesh_lines_color
            (unless (or (symbolp (third value)) (stringp (third value)))
-             (merror (intl:gettext "mesh_lines_color: must be symbol or string")))
+             (merror (intl:gettext "set_plot_option: mesh_lines_color must be a symbol or string; found: ~M") (third value)))
            value)
           ($gnuplot_term
            (unless (or (symbolp (third value)) (stringp (third value)))
-               (merror (intl:gettext "gnuplot_term: must be symbol or string")))
+               (merror (intl:gettext "set_plot_option: gnuplot_term must be a symbol or string; found: ~M") (third value)))
            value)
           ($gnuplot_out_file value)
           ($gnuplot_curve_titles (if ($listp value)
@@ -275,7 +275,7 @@ sin(y)*(10.0+6*cos(x)),
           ($plot_realpart value)
           (t
            (merror
-            (intl:gettext "set_plot_option: Unknown plot option specified: ~M")
+            (intl:gettext "set_plot_option: unknown plot option: ~M")
             name))))
 
   (let ((v (rassoc name (cdr $plot_options) :test #'(lambda (a b) (eq a (car b))))))
@@ -410,7 +410,7 @@ sin(y)*(10.0+6*cos(x)),
 ;; pts is a vector of bts [x0,y0,z0,x1,y1,z1,...] and each tuple xi,yi,zi is rotated
 ;; also the *z-range* is computed.
 #-abcl (defun $rotate_pts(pts rotation-matrix)
-  (or ($matrixp rotation-matrix) (error "second arg not matrix"))
+  (or ($matrixp rotation-matrix) (merror (intl:gettext "rotate_pts: second argument must be a matrix.")))
   (let* ((rot *rot*)
          (l (length pts))
          (x 0.0) (y 0.0) (z 0.0)
@@ -551,21 +551,25 @@ sin(y)*(10.0+6*cos(x)),
 ;;   name of a simplifying function
 ;; EXPR is a Maxima lambda expression
 ;; EXPR is a general Maxima expression
-
-(defun coerce-float-fun (expr &optional lvars)
+;;
+;; %COERCE-FLOAT-FUN is the main internal routine for this.
+;; COERCE-FLOAT-FUN is the user interface for creating a function that
+;; returns floats.  COERCE-BFLOAT-FUN is the same, except bfloats are
+;; returned.
+(defun %coerce-float-fun (float-fun expr &optional lvars)
   (cond ((and (consp expr) (functionp expr))
          (let ((args (if lvars (cdr lvars) (list (gensym)))))
-           (coerce-lisp-function-or-lisp-lambda args expr)))
+           (coerce-lisp-function-or-lisp-lambda args expr :float-fun float-fun)))
         ;; expr is a string which names an operator
         ;; (e.g. "!" "+" or a user-defined operator)
         ((and (stringp expr) (getopr0 expr))
          (let ((a (if lvars lvars `((mlist) ,(gensym)))))
-           (coerce-float-fun `(($apply) ,(getopr0 expr) ,a) a)))
+           (%coerce-float-fun float-fun `(($apply) ,(getopr0 expr) ,a) a)))
         ((and (symbolp expr) (not (member expr lvars)) (not ($constantp expr)))
          (cond
            ((fboundp expr)
             (let ((args (if lvars (cdr lvars) (list (gensym)))))
-              (coerce-lisp-function-or-lisp-lambda args expr)))
+              (coerce-lisp-function-or-lisp-lambda args expr :float-fun float-fun)))
 
            ;; expr is name of a Maxima function defined by := or
            ;; define
@@ -573,7 +577,7 @@ sin(y)*(10.0+6*cos(x)),
             (let*
                 ((mexpr (mget expr 'mexpr))
                  (args (cdr (second mexpr))))
-              (coerce-maxima-function-or-maxima-lambda args expr)))
+              (coerce-maxima-function-or-maxima-lambda args expr :float-fun float-fun)))
 
            ((or
              ;; expr is the name of a function defined by defmspec
@@ -589,122 +593,141 @@ sin(y)*(10.0+6*cos(x)),
              ;; form
              (get ($verbify expr) 'operators))
             (let ((a (if lvars lvars `((mlist) ,(gensym)))))
-              (coerce-float-fun `(($apply) ,expr ,a) a)))
+              (%coerce-float-fun float-fun `(($apply) ,expr ,a) a)))
            (t
-            (merror "Undefined function ~M" expr))))
+            (merror (intl:gettext "COERCE-FLOAT-FUN: no such Lisp or Maxima function: ~M") expr))))
 
-    ((and (consp expr) (eq (caar expr) 'lambda))
-     (let ((args (cdr (second expr))))
-       (coerce-maxima-function-or-maxima-lambda args expr)))
+	((and (consp expr) (eq (caar expr) 'lambda))
+	 (let ((args (cdr (second expr))))
+	   (coerce-maxima-function-or-maxima-lambda args expr :float-fun float-fun)))
 
         (t
          (let* ((vars (or lvars ($sort ($listofvars expr))))
-            (subscripted-vars ($sublist vars '((lambda) ((mlist) $x) ((mnot) (($atom) $x)))))
-            gensym-vars save-list-gensym subscripted-vars-save
-            subscripted-vars-mset subscripted-vars-restore)
+		(subscripted-vars ($sublist vars '((lambda) ((mlist) $x) ((mnot) (($atom) $x)))))
+		gensym-vars save-list-gensym subscripted-vars-save
+		subscripted-vars-mset subscripted-vars-restore)
 
-       ;; VARS and SUBSCRIPTED-VARS are Maxima lists.  Other lists are
-       ;; Lisp lists.
-       (when (cdr subscripted-vars)
-         (setq gensym-vars (mapcar #'(lambda (ign) (declare (ignore ign)) (gensym))
-                                   (cdr subscripted-vars)))
-         (mapcar #'(lambda (a b) (setq vars (subst b a vars :test 'equal)))
-                 (cdr subscripted-vars) gensym-vars)
+	   ;; VARS and SUBSCRIPTED-VARS are Maxima lists.  Other lists are
+	   ;; Lisp lists.
+	   (when (cdr subscripted-vars)
+	     (setq gensym-vars (mapcar #'(lambda (ign) (declare (ignore ign)) (gensym))
+				       (cdr subscripted-vars)))
+	     (mapcar #'(lambda (a b) (setq vars (subst b a vars :test 'equal)))
+		     (cdr subscripted-vars) gensym-vars)
 
-         ;; This stuff about saving and restoring array variables
-         ;; should go into MBINDING, and the lambda expression
-         ;; constructed below should call MBINDING.  (At present
-         ;; MBINDING barfs on array variables.)
-         (setq save-list-gensym (gensym))
-         (setq subscripted-vars-save
-               (mapcar #'(lambda (a) `(push (meval ',a) ,save-list-gensym))
-                       (cdr subscripted-vars)))
-         (setq subscripted-vars-mset
-               (mapcar #'(lambda (a b) `(mset ',a ,b))
-                       (cdr subscripted-vars) gensym-vars))
-         (setq subscripted-vars-restore
-               (mapcar #'(lambda (a) `(mset ',a (pop ,save-list-gensym)))
-                       (reverse (cdr subscripted-vars)))))
+	     ;; This stuff about saving and restoring array variables
+	     ;; should go into MBINDING, and the lambda expression
+	     ;; constructed below should call MBINDING.  (At present
+	     ;; MBINDING barfs on array variables.)
+	     (setq save-list-gensym (gensym))
+	     (setq subscripted-vars-save
+		   (mapcar #'(lambda (a) `(push (meval ',a) ,save-list-gensym))
+			   (cdr subscripted-vars)))
+	     (setq subscripted-vars-mset
+		   (mapcar #'(lambda (a b) `(mset ',a ,b))
+			   (cdr subscripted-vars) gensym-vars))
+	     (setq subscripted-vars-restore
+		   (mapcar #'(lambda (a) `(mset ',a (pop ,save-list-gensym)))
+			   (reverse (cdr subscripted-vars)))))
 
-       (coerce
-        `(lambda ,(cdr vars)
-           (declare (special ,@(cdr vars) errorsw))
+	   (coerce
+	    `(lambda ,(cdr vars)
+	       (declare (special ,@(cdr vars) errorsw))
 
-           ;; Nothing interpolated here when there are no subscripted
-           ;; variables.
-           ,@(if save-list-gensym `((declare (special ,save-list-gensym))))
+	       ;; Nothing interpolated here when there are no subscripted
+	       ;; variables.
+	       ,@(if save-list-gensym `((declare (special ,save-list-gensym))))
 
-           ;; Nothing interpolated here when there are no subscripted
-           ;; variables.
-           ,@(if (cdr subscripted-vars)
-                 `((progn (setq ,save-list-gensym nil)
-                          ,@(append subscripted-vars-save subscripted-vars-mset))))
+	       ;; Nothing interpolated here when there are no subscripted
+	       ;; variables.
+	       ,@(if (cdr subscripted-vars)
+		     `((progn (setq ,save-list-gensym nil)
+			      ,@(append subscripted-vars-save subscripted-vars-mset))))
 
-           (let (($ratprint nil) ($numer t) (nounsflag t)
-                 (errorsw t)
-                 (errcatch t))
-             (declare (special errcatch))
-             ;; Catch any errors from evaluating the
-             ;; function.  We're assuming that if an error
-             ;; is caught, the result is not a number.  We
-             ;; also assume that for such errors, it's
-             ;; because the function is not defined there,
-             ;; not because of some other maxima error.
-             ;;
-             ;; GCL 2.6.2 has handler-case but not quite ANSI yet. 
-             (let ((result
-                    #-gcl
-                     (handler-case 
-                         (catch 'errorsw
-                           ($float (maybe-realpart (meval* ',expr))))
-                       ;; Should we just catch all errors here?  It is
-                       ;; rather nice to only catch errors we care
-                       ;; about and let other errors fall through so
-                       ;; that we don't pretend to do something when
-                       ;; it is better to let the error through.
-                       (arithmetic-error () t)
-                       (maxima-$error () t))
-                     #+gcl
-                     (handler-case 
-                         (catch 'errorsw
-                           ($float (maybe-realpart (meval* ',expr))))
-                       (cl::error () t))
-                     ))
+	       (let (($ratprint nil)
+		     ;; We don't want to set $numer to T when coercing
+		     ;; to a bigfloat.  By doing so, things like
+		     ;; log(400)^400 get converted to double-floats,
+		     ;; which causes a double-float overflow.  But the
+		     ;; whole point of coercing to bfloat is to use
+		     ;; bfloats, not doubles.
+		     ;;
+		     ;; Perhaps we don't even need to do this for
+		     ;; double-floats?  It would be nice to remove
+		     ;; this.  For backward compatibility, we bind
+		     ;; numer to T if we're not trying to bfloat.
+		     ($numer ,(not (eq float-fun '$bfloat)))
+		     (*nounsflag* t)
+		     (errorsw t)
+		     (errcatch t))
+		 (declare (special errcatch))
+		 ;; Catch any errors from evaluating the
+		 ;; function.  We're assuming that if an error
+		 ;; is caught, the result is not a number.  We
+		 ;; also assume that for such errors, it's
+		 ;; because the function is not defined there,
+		 ;; not because of some other maxima error.
+		 ;;
+		 ;; GCL 2.6.2 has handler-case but not quite ANSI yet. 
+		 (let ((result
+			#-gcl
+			 (handler-case 
+			     (catch 'errorsw
+			       (,float-fun (maybe-realpart (meval* ',expr))))
+			   ;; Should we just catch all errors here?  It is
+			   ;; rather nice to only catch errors we care
+			   ;; about and let other errors fall through so
+			   ;; that we don't pretend to do something when
+			   ;; it is better to let the error through.
+			   (arithmetic-error () t)
+			   (maxima-$error () t))
+			 #+gcl
+			 (handler-case 
+			     (catch 'errorsw
+			       (,float-fun (maybe-realpart (meval* ',expr))))
+			   (cl::error () t))
+			 ))
 
-               ;; Nothing interpolated here when there are no
-               ;; subscripted variables.
-               ,@(if (cdr subscripted-vars) `((progn ,@subscripted-vars-restore)))
+		   ;; Nothing interpolated here when there are no
+		   ;; subscripted variables.
+		   ,@(if (cdr subscripted-vars) `((progn ,@subscripted-vars-restore)))
 
-               result)))
-        'function)))))
+		   result)))
+	    'function)))))
 
-(defun coerce-maxima-function-or-maxima-lambda (args expr)
+(defun coerce-float-fun (expr &optional lvars)
+  (%coerce-float-fun '$float expr lvars))
+
+(defun coerce-bfloat-fun (expr &optional lvars)
+  (%coerce-float-fun '$bfloat expr lvars))
+
+(defun coerce-maxima-function-or-maxima-lambda (args expr &key (float-fun '$float))
   (let ((gensym-args (loop for x in args collect (gensym))))
     (coerce
       `(lambda ,gensym-args (declare (special ,@gensym-args))
          (let* (($ratprint nil)
                 ($numer t)
-                (nounsflag t)
+                (*nounsflag* t)
                 (result (maybe-realpart (mapply ',expr (list ,@gensym-args) t))))
            ;; Just always try to convert the result to a float, which
            ;; handles things like $%pi.  See also BUG #2880115
            ;; http://sourceforge.net/tracker/?func=detail&atid=104933&aid=2880115&group_id=4933
-           ($float result)))
+           (,float-fun result)))
       'function)))
 
 ;; Same as above, but call APPLY instead of MAPPLY.
 
-(defun coerce-lisp-function-or-lisp-lambda (args expr)
+(defun coerce-lisp-function-or-lisp-lambda (args expr &key (float-fun '$float))
   (let ((gensym-args (loop for x in args collect (gensym))))
     (coerce
       `(lambda ,gensym-args (declare (special ,@gensym-args))
          (let* (($ratprint nil)
                 ($numer t)
-                (nounsflag t)
+                (*nounsflag* t)
                 (result (maybe-realpart (apply ',expr (list ,@gensym-args)))))
            ;; Always use $float.  See comment for
            ;; coerce-maxima-function-ormaxima-lambda above.
-           ($float result)))
+           (,float-fun result)))
       'function)))
 
 (defmacro zval (points verts i) `(aref ,points (+ 2 (* 3 (aref ,verts ,i)))))
@@ -805,7 +828,7 @@ sin(y)*(10.0+6*cos(x)),
           ((typep lis 'cons)
            ($copy_pts (cdr lis) vec  ($copy_pts (car lis) vec start)))
           ((symbolp lis) start)
-          (t (error "bad lis")))))
+          (t (merror (intl:gettext "copy_pts: unrecognized first argument: ~M") lis)))))
 
 ;; parametric ; [parametric,xfun,yfun,[t,tlow,thigh],[nticks ..]]
 ;; the rest of the parametric list after the list will be pushed plot_options
@@ -868,18 +891,18 @@ sin(y)*(10.0+6*cos(x)),
          (cond
            ((= (length f) 4)                 ; [discrete,x,y]
             (if (not ($listp x))
-              (merror "draw2d (discrete): ~M must be a list." x))
+              (merror (intl:gettext "draw2d (discrete): argument must be a list; found: ~M") x))
             (if (not ($listp y))
-              (merror "draw2d (discrete): ~M must be a list." y))
+              (merror (intl:gettext "draw2d (discrete): argument must be a list; found: ~M") y))
             (cons '(mlist) (mapcan #'list (rest x) (rest y))))
            ((= (length f) 3)                 ; [discrete,xy]
             (if (not ($listp x))
-              (merror "draw2d (discrete): ~M must be a list." x))
+              (merror (intl:gettext "draw2d (discrete): argument must be a list; found: ~M") x))
             (let ((tmp (mapcar #'rest (rest x))))
               (cons '(mlist) (mapcan #'append tmp))))
            (t                                ; error
              (merror
-               "draw2d (discrete): expression is not of the form [discrete,x,y] or ~%[discrete,xy].")))))
+               (intl:gettext "draw2d (discrete): argument must be [discrete, x, y] or [discrete, xy]; found: ~M") f)))))
 
       ;; Encourage non-floats to become floats here.
 
@@ -1102,16 +1125,16 @@ sin(y)*(10.0+6*cos(x)),
           (if (null result-sans-nil)
             (cond
               ((= n-non-numeric 0)
-               (mtell "plot2d: all values were clipped.~%"))
+               (mtell (intl:gettext "plot2d: all values were clipped.~%")))
               ((= n-clipped 0)
-               (mtell "plot2d: expression evaluates to non-numeric value everywhere in plotting range.~%"))
+               (mtell (intl:gettext "plot2d: expression evaluates to non-numeric value everywhere in plotting range.~%")))
               (t
-                (mtell "plot2d: all values are non-numeric, or clipped.~%")))
+                (mtell (intl:gettext "plot2d: all values are non-numeric, or clipped.~%"))))
             (progn
               (if (> n-non-numeric 0)
-                (mtell "plot2d: expression evaluates to non-numeric value somewhere in plotting range.~%"))
+                (mtell (intl:gettext "plot2d: expression evaluates to non-numeric value somewhere in plotting range.~%")))
               (if (> n-clipped 0)
-                (mtell "plot2d: some values were clipped.~%"))))
+                (mtell (intl:gettext "plot2d: some values were clipped.~%")))))
           (cons '(mlist) result-sans-nil))))))
 
 (defun get-range (lis)
@@ -1173,7 +1196,7 @@ sin(y)*(10.0+6*cos(x)),
         ($dumb
          (if gnuplot-out-file
              ($printfile view-file)
-             (merror "Plot option `gnuplot_out_file' not defined."))))) 
+             (merror (intl:gettext "plotting: option 'gnuplot_out_file' not defined."))))))
     (if gnuplot-out-file
         gnuplot-out-file-string
         "")))
@@ -1218,7 +1241,7 @@ sin(y)*(10.0+6*cos(x)),
            ($set_plot_option `((mlist simp) $gnuplot_out_file ,(third v)))
            (setf (getf features :psfile) (ensure-string (third v))))
           (t ($set_plot_option v)))
-        (merror "Option ~M should be a list" v)))
+        (merror (intl:gettext "plotting: argument must be a list; found: ~M") v)))
   (when ($get_plot_option '$axes 2)
     (setf (getf features :axes) ($get_plot_option '$axes 2)))
   (setf (getf features :grid) ($get_plot_option '$grid))
@@ -1342,21 +1365,21 @@ sin(y)*(10.0+6*cos(x)),
         (if (> xmax 0)
             (when (<= xmin 0)
               (let ((revised-xmin (/ xmax 1000)))
-                (mtell "plot2d: lower bound must be positive when 'logx' in effect.~%plot2d: assuming lower bound = ~M instead of ~M" revised-xmin xmin)
+                (mtell (intl:gettext "plot2d: lower bound must be positive when 'logx' in effect.~%plot2d: assuming lower bound = ~M instead of ~M") revised-xmin xmin)
                 (setf (getf features :xmin) revised-xmin)
                 (setq range `((mlist) ,(second range) ,revised-xmin ,xmax))
                 ($set_plot_option `((mlist) $x ,revised-xmin ,xmax))))
-            (merror "plot2d: upper bound must be positive when 'logx' in effect; found: ~M" xmax))))
+            (merror (intl:gettext "plot2d: upper bound must be positive when 'logx' in effect; found: ~M") xmax))))
 
     (let ((ymin (getf features :ymin)) (ymax (getf features :ymax)))
       (when (and (getf features :log-y) ymin ymax)
         (if (> ymax 0)
             (when (<= ymin 0)
               (let ((revised-ymin (/ ymax 1000)))
-                (mtell "plot2d: lower bound must be positive when 'logy' in effect.~%plot2d: assuming lower bound = ~M instead of ~M" revised-ymin ymin)
+                (mtell (intl:gettext "plot2d: lower bound must be positive when 'logy' in effect.~%plot2d: assuming lower bound = ~M instead of ~M") revised-ymin ymin)
                 (setf (getf features :ymin) revised-ymin)
                 ($set_plot_option `((mlist) $y ,revised-ymin ,ymax))))
-            (merror "plot2d: upper bound must be positive when 'logy' in effect; found: ~M" ymax))))
+            (merror (intl:gettext "plot2d: upper bound must be positive when 'logy' in effect; found: ~M") ymax))))
 
     (setq *plot-realpart* ($get_plot_option '$plot_realpart 2))
 
@@ -1365,7 +1388,7 @@ sin(y)*(10.0+6*cos(x)),
 
     (setq points-lists (mapcar #'(lambda (f) (cdr (draw2d f range features))) (cdr fun)))
     (when (= (count-if #'(lambda (x) x) points-lists) 0)
-      (mtell "plot2d: nothing to plot.~%")
+      (mtell (intl:gettext "plot2d: nothing to plot.~%"))
       (return-from $plot2d))
 
     (setq gnuplot-term ($get_plot_option '$gnuplot_term 2))
@@ -1603,25 +1626,26 @@ output-file))
   (and (symbolp x) (char= (char (symbol-value x) 0) #\$)))
 
 
-(defun $tcl_output  (lis i &optional (skip 2))
-  (or (typep i 'fixnum) (error "~a should be an integer" i ))
-  ($listp_check 'list lis )
+(defun $tcl_output (lis i &optional (skip 2))
+  (when (not (typep i 'fixnum))
+    (merror
+      (intl:gettext "tcl_ouput: second argument must be an integer; found ~M")
+                    i))
+  (when (not ($listp lis))
+    (merror
+      (intl:gettext "tcl_output: first argument must be a list; found ~M") lis))
   (format *standard-output* "~% {")
   (cond (($listp (second lis))
          (loop for v in lis
                 do
-                (format *standard-output* "~,10g " (nth i v)))
-         )
+                (format *standard-output* "~,10g " (nth i v))))
         (t
          (setq lis (nthcdr i lis))
          (loop  with v = lis  while v
                  do
                  (format *standard-output* "~,10g " (car v))
-                 (setq v (nthcdr skip v))
-                 )
-         ))
-  (format *standard-output* "~% }")
-  )
+                 (setq v (nthcdr skip v)))))
+  (format *standard-output* "~% }"))
 
 
 (defun tcl-output-list ( st lis )
@@ -1657,10 +1681,10 @@ output-file))
            (< a b))
       (if range
           (merror 
-           "Bad range: ~M.~%Range must be of the form [variable,min,max]"
+           (intl:gettext "plotting: range must be of the form [variable, min, max]; found: ~M")
            range)
           (merror 
-           "No range given. Must supply range of the form [variable,min,max]")))
+           (intl:gettext "plotting: no range given; must supply range of the form [variable, min, max]"))))
   `((mlist) ,(car tem) ,(float a) ,(float b)))
 
 (defun $zero_fun (x y) x y 0.0)
@@ -1743,7 +1767,7 @@ output-file))
              (not (member plot-format-in-plot-options gnuplot-formats :test #'eq))))
 
       (progn
-        (mtell "contour_plot: plot_format = ~a not understood; must be a gnuplot format.~%"
+        (mtell (intl:gettext "contour_plot: plot_format = ~a not recognized; must be a gnuplot format.~%")
                (ensure-string (or plot-format-in-arguments plot-format-in-plot-options)))
         (return-from $contour_plot))
 
@@ -1813,15 +1837,16 @@ output-file))
      lvars trans xrange yrange *original-points*
      functions exprn domain tem ($plot_options $plot_options)
      ($in_netmath $in_netmath) features
+     (*plot-realpart* *plot-realpart*)
      gnuplot-term gnuplot-out-file file titles (output-file "")
      (usage (intl:gettext
 "plot3d: Usage.
 To plot a single function f of 2 variables v1 and v2:
-  plot3d ( f, [v1, min, max], [v2, min, max], options )
-a parametric representation of a surface with parameters v1 and v2:
-  plot3d ( [f1, f2, f3], [v1, min, max], [v2, min, max], options
-several functions depending on the two variables v1 and v2:
-  plot3d ( [f1, f2, ..., fn], [v1, min, max], [v2, min, max], options")))
+  plot3d (f, [v1, min, max], [v2, min, max], options)
+A parametric representation of a surface with parameters v1 and v2:
+  plot3d ([f1, f2, f3], [v1, min, max], [v2, min, max], options)
+Several functions depending on the two variables v1 and v2:
+  plot3d ([f1, f2, ..., fn, [v1, min, max], [v2, min, max]], options)")))
   
   (declare (special *original-points*))
   (setf (getf features :type) "plot3d")
@@ -1881,7 +1906,7 @@ several functions depending on the two variables v1 and v2:
                         (setf (getf features :const-expr)
                               ($float (meval (fourth exprn))))))
                     (merror
-                     (intl:gettext "plot3d: wrong number of variables: ~M. There should be two")
+                     (intl:gettext "plot3d: there must be two variables; found: ~M")
                      lvars))))
              
              (3
@@ -1898,7 +1923,7 @@ several functions depending on the two variables v1 and v2:
              (t
               ;; syntax error. exprn does not have the expected form
               (merror
-               (intl:gettext "plot3d: invalid argument ~M~%Expecting [expr1, expr2, expr3]")
+               (intl:gettext "plot3d: argument must be a list of three expressions; found: ~M")
                exprn))))
          (progn
            ;; exprn is a simple function, defined in the global domain.
@@ -1947,13 +1972,17 @@ several functions depending on the two variables v1 and v2:
   ;; parse the options given to plot3d
   (setq features (plot-options-parser options features))
   (setq tem ($get_plot_option '$transform_xy 2))
+  (setq *plot-realpart* ($get_plot_option '$plot_realpart 2))
   
   ;; set up the labels for the axes
   (when (or (null (getf features :box)) (first (getf features :box)))
     (if (and (getf features :xvar) (getf features :yvar) (null tem))
 	(progn
-	  (setf (getf features :xlabel) (ensure-string (getf features :xvar)))
-	  (setf (getf features :ylabel) (ensure-string (getf features :yvar))))
+	  ;; Don't set xlabel (ylabel) if the user specified one.
+	  (unless (getf features :xlabel)
+	    (setf (getf features :xlabel) (ensure-string (getf features :xvar))))
+	  (unless (getf features :ylabel)
+	    (setf (getf features :ylabel) (ensure-string (getf features :yvar)))))
 	(progn
 	  (setf (getf features :xlabel) "x")
 	  (setf (getf features :ylabel) "y")))
@@ -2026,7 +2055,7 @@ several functions depending on the two variables v1 and v2:
                         (rest ($listofvars (mfuncall fun (second lvars)
                                                      (third lvars))))))
                   (merror
-                   (intl:gettext "plot3d: Wrong usage.~%Expecting <expr. with var1 and var2>, [var1, min, max], [var2, min, max]")))))
+                   (intl:gettext "plot3d: expected <expr. of v1 and v2>, [v1, min, max], [v2, min, max]")))))
           (let* ((pl
                   (draw3d
                    fun (third xrange) (fourth xrange) (third yrange)
