@@ -28,39 +28,62 @@
 
 (declare-top (special $zerobern ivars key-vars tlist %e-val))
 
-(defun lisimp (exp vestigial z)
+(defun lisimp (expr vestigial z)
   (declare (ignore vestigial))
-  (let ((s (simpcheck (car (subfunsubs exp)) z))
-	($zerobern t)
-	(a))
-    (subargcheck exp 1 1 '$li)
-    (setq a (simpcheck (car (subfunargs exp)) z))
-    (or (cond ((eql a 0) 0)
-	      ((not (integerp s)) ())
-	      ((= s 1) (m- `((%log) ,(m- 1 a))))
-	      ((and (integerp a) (> s 1)
-		    (cond ((= a 1) ($zeta s))
-			  ((= a -1)
-			   (m*t (m1- `((rat) 1 ,(expt 2 (- s 1))))
-				($zeta s))))))
-	      ((= s 2) (li2simp a))
-	      ((= s 3) (li3simp a)))
-	(eqtest (subfunmakes '$li (ncons s) (ncons a))
-		exp))))
+  (let ((s (simpcheck (car (subfunsubs expr)) z))
+        ($zerobern t)
+        (a))
+    (subargcheck expr 1 1 '$li)
+    (setq a (simpcheck (car (subfunargs expr)) z))
+    (or (cond ((zerop1 a) a)
+              ((not (integerp s)) ())
+              ((= s 1)
+               (if (onep1 a)
+                   (simp-domain-error
+                     (intl:gettext "li: li[~:M](~:M) is undefined.") s a)
+                   (neg (take '(%log) (sub 1 a)))))
+              ((= s 0) (div a (sub 1 a)))
+              ((< s 0) (lisimp-negative-integer s a))
+              ((and (integerp a) (> s 1)
+                    (cond ((= a 1) (take '(%zeta) s))
+                          ((= a -1)
+                           (mul (add -1 (inv (expt 2 (- s 1))))
+                                (take '(%zeta) s))))))
+              ((= s 2) (li2simp a))
+              ((= s 3) (li3simp a)))
+        (eqtest (subfunmakes '$li (ncons s) (ncons a))
+                expr))))
+
+;; Expand the Polylogarithm li[s](z) for a negative integer parameter s.
+(defun lisimp-negative-integer (s z)
+  (let ((n (- s)))
+    (mul (inv (power (sub 1 z) (+ n 1)))
+         (let ((index1 (gensumindex))
+               ($simpsum t))
+           (dosum
+             (mul (power z index1)
+                  (let ((index2 (gensumindex)))
+                    (dosum
+                      (mul (power -1 (add index2 1))
+                           (take '(%binomial) (+ n 1) (sub index2 1))
+                           (power (add 1 (sub index1 index2)) n))
+                      index2 1 index1 t)))
+             index1 1 n t)))))
 
 (defun li2simp (arg)
   (cond ((mnumericalp arg) (li2numer (float arg)))
-	((alike1 arg '((rat) 1 2))
-	 (m+t (m// ($zeta 2) 2)
-	      (m*t '((rat simp) -1 2)
-		   (m^ '((%log) 2) 2))))))
+        ((alike1 arg '((rat) 1 2))
+         (add (div (take '(%zeta) 2) 2)
+              (mul '((rat simp) -1 2)
+                   (power (take '(%log) 2) 2))))))
 
 (defun li3simp (arg)
   (cond ((mnumericalp arg) (li3numer (float arg)))
-	((alike1 arg '((rat) 1 2))
-	 (m+t (m* '((rat simp) 7 8) '(($zeta) 3))
-	      (m*t (m// ($zeta 2) -2) (simplify '((%log) 2)))
-	      (m*t '((rat simp) 1 6) (m^ '((%log) 2) 3))))))
+        ((alike1 arg '((rat) 1 2))
+         (add (mul '((rat simp) 7 8) (take '(%zeta) 3))
+              (mul (div (take '(%zeta) 2) -2) (take '(%log) 2))
+              (mul '((rat simp) 1 6) (power (take '(%log) 2) 3))))))
+
 
 ;; Numerical evaluation for Chebyschev expansions of the first kind
 
@@ -206,12 +229,14 @@
 	'($maxpsiposint $maxpsinegint $maxpsifracnum $maxpsifracdenom)
 	'(20. -10. 6 6))
 
-(defun psisimp (exp a z)
-  (let ((s (simpcheck (car (subfunsubs exp)) z)))
-    (subargcheck exp 1 1 '$psi)
-    (setq a (simpcheck (car (subfunargs exp)) z))
-    (and (integerp a) (< a 1) (pole-err exp))
-    (eqtest (psisimp1 s a) exp)))
+(defun psisimp (expr a z)
+  (let ((s (simpcheck (car (subfunsubs expr)) z)))
+    (subargcheck expr 1 1 '$psi)
+    (setq a (simpcheck (car (subfunargs expr)) z))
+    (and (setq z (integer-representation-p a))
+         (< z 1)
+         (pole-err expr))
+    (eqtest (psisimp1 s a) expr)))
 
 ;; This gets pretty hairy now.
 
@@ -373,7 +398,7 @@
 	(t (prog1
 	       (cons (* sign *last*) 1)
 	     (setq *last*
-		   (*quo (* *last* (+ subl (1+ k)))
+		   (quot (* *last* (+ subl (1+ k)))
 			 (1+ k)))))))
 
 (defun plygam-ord (subl)
