@@ -27,8 +27,8 @@
 
 (declare-top  (special bindlist loclist errset *rset ^q lf tab ff cr
 		       $values $functions $arrays $gradefs $dependencies
-		       $rules $props $ratvars $ratvarswitch
-		       varlist genvar $filename
+		       $rules $props $ratvars
+		       varlist genvar
 		       $gensumnum checkfactors $features featurel
 		       $weightlevels tellratlist $dontfactor
 		       dispflag savefile $%% $error smart-tty
@@ -36,11 +36,6 @@
 		       $stringdisp $lispdisp defaultf command
 		       transp $contexts $setcheck $macros autoload))
 
-(mapc #'(lambda (x) (putprop (car x) (cadr x) 'opalias))
-      '((+ $+) (- $-) (* $*) (// $//) (^ $^) (|.| |$.|) (< $<) (= $=)
-	(> $>) (|(| |$(|) (|)| |$)|) (|[| |$[|) (|]| |$]|) (|,| |$,|) (|:| |$:|)
-	(|!| |$!|) (|#| |$#|) (|'| |$'|) (|;| |$;|)))
-
 (mapc #'(lambda (x) (setf (symbol-value (car x))
 			 (cond ((char< (cadr x) #.(code-char 160.))
 				(ascii (cadr x)))
@@ -48,9 +43,9 @@
       '((tab #\tab) (lf #\linefeed) (ff #\page) (cr #\return) (sp #\space)))
 
 (defvar thistime 0)
-(defvar refchkl nil)
+(defvar *refchkl* nil)
 (defvar *mdebug* nil)
-(defvar baktrcl nil)
+(defvar *baktrcl* nil)
 (defvar errbrksw nil)
 (defvar mbreak nil)
 (defvar errcatch nil)
@@ -69,7 +64,6 @@
 (defvar pos nil)
 (defvar dcount 0)
 (defvar dskfnp nil)
-(defvar dsksavep nil)
 (defvar saveno 0)
 (defvar quitmsg  " ")
 (defvar more-^w nil)
@@ -77,9 +71,6 @@
 
 (defvar state-pdl (ncons 'lisp-toplevel))
 
-(defmvar $filenum 0)
-(defmvar $storenum 1000.)
-(defmvar $dskall t)
 (defmvar $errorfun nil)
 (defmvar $disptime nil)
 (defmvar $strdisp t)
@@ -98,7 +89,6 @@
                  $dependencies $let_rule_packages $structures))
 
 (defmvar $labels (list '(mlist simp)))
-(defmvar $device '$dsk)
 (defmvar $dispflag t)
 
 (defmvar $% '$% "The last out-line computed, corresponds to lisp *"
@@ -116,10 +106,6 @@
 (defmvar $linenum 1 "the line number of the last expression."
 	 fixnum no-reset)
 
-(defmvar $direc 'jrmu
-  "The default file directory for `save', `store', `fassave', and `stringout'."
-  no-reset)
-
 (defmvar $file_output_append nil
   "Flag to tell file-writing functions whether to append or clobber the output file.")
 
@@ -137,21 +123,17 @@
 (defun sys-gctime ()
   (status gctime))
 
-;(defmfun meval* (test)
-;  (let (refchkl baktrcl checkfactors)
-;    (prog2 (if $ratvarswitch (setq varlist (cdr $ratvars)))
-;	(meval test)
-;      (clearsign))))
-
-;; This version of meval* makes sure that the facts from the global variable
+;; This version of meval* makes sure, that the facts from the global variable
 ;; locals are cleared with a call to clearsign. The facts are added by asksign
-;; and friends. meval* function is only used for top level evaluations.
+;; and friends. The function meval* is only used for top level evaluations.
 ;; For other cases the function meval can be used.
 
+(defmvar $ratvarswitch t) ; If T, start an evaluation with a fresh list VARLIST.
+
 (defun meval* (expr)
   ;; Make sure that clearsign is called after the evaluation.
   (unwind-protect
-    (let (refchkl baktrcl checkfactors)
+    (let (*refchkl* *baktrcl* checkfactors)
       (if $ratvarswitch (setq varlist (cdr $ratvars)))
       (meval expr))
     ;; Clear the facts from asksign and friends.
@@ -243,14 +225,10 @@
   (let ((file (get func 'autoload)))
     (if file (funcall autoload (cons func file)))))
 
-(defmfun load-file (file)
-  ($load (to-macsyma-namestring file)))
-
 (defmspec $loadfile (form)
   (loadfile (namestring (maxima-string (meval (cadr form)))) nil
 	    (not (member $loadprint '(nil $autoload) :test #'equal))))
 
-
 (defun $setup_autoload (filename &rest functions)
   (let ((file ($file_search filename)))
     (dolist (func functions)
@@ -280,7 +258,6 @@
 	(t (merror "Not a proper filename ~M" file)))
   (filestrip file))
 
-
 (defmfun loadfile (file findp printp &aux (saveno 0))
   (and findp (member $loadprint '(nil $loadfile) :test #'equal) (setq printp nil))
   ;; Should really get the truename of FILE.
@@ -294,24 +271,11 @@
 (defun $directory (path)
   (cons '(mlist) (mapcar 'namestring (directory ($filename_merge path)))))
 
-(defmfun truefname (file)
-  (probe-file file))
-
-(defmfun carfile (file)		       ; FILE is in OldIO list format.
-  (if (= (length file) 3) (cdr file) file))
-
-;; SPECP is T if the file is being batched for TRANSL, or $LOAD,
-;;	or some other special purpose.
-
-(defmacro filepos-check ()
-  `(if specp (setq filepos (filepos file-obj))))
-
 (defmspec $kill (form)
   (clear)	;; get assume db into consistent state
   (mapc #'kill1 (cdr form))
   '$done)
 
-
 ;;; The following *builtin- variables are used to keep/restore builtin
 ;;; symbols and values during kill operations. Their values are set at
 ;;; the end of init-cl.lisp, after all symbols have been defined.
@@ -347,6 +311,7 @@
 			 (remove-transl-fun-props x)
 			 (remove-transl-array-fun-props x)))
       (when (not (get x 'sysconst))
+	(remprop x 'lineinfo)
 	(remprop x 'mprops))
       (dolist (u '(bindtest nonarray evfun evflag opers special mode))
 	(remprop x u))
@@ -531,8 +496,8 @@
 	      (setq  errset 'errbreak1)
 	      (setq tim (get-internal-run-time)
 		    $%% '$%%
-		    ;; just in case baktrcl is cons'd on the stack
-		    $backtrace (cons '(mlist simp) (copy-list baktrcl)))
+		    ;; just in case *baktrcl* is cons'd on the stack
+		    $backtrace (cons '(mlist simp) (copy-list *baktrcl*)))
 	      (setq o^r #.writefilep #.writefilep (and #.writefilep (not dskfnp)))
 	      (cond ((eq y 'noprint))
 		    (t
@@ -1021,9 +986,6 @@
 
 ;; File-processing stuff.
 
-(defun mfile nil
-  (fullstrip (list $filename (setq $filenum (1+ $filenum)) $device $direc)))
-
 ;; This prevents single blank lines from appearing at the top of video
 ;; terminals.  If at the upper left corner and we want to print a blank
 ;; line, leave the cursor there and send the blank line to transcript
