@@ -89,6 +89,8 @@
 
 (defmspec $compfile (forms)
     (setq forms (cdr forms))
+    (if (eq 1 (length forms))
+      (merror "compfile: bravely refusing to write file of length 0"))
     (bind-transl-state
      (setq $transcompile t
 	   *in-compfile* t)
@@ -99,7 +101,7 @@
        (pop forms)
        (unwind-protect
 	    (progn
-	      (setq transl-file (open-out-dsk out-file-name))
+	      (setq transl-file (open out-file-name :direction :output :if-exists :overwrite :if-does-not-exist :create :element-type 'character))
 	      (cond ((or (member '$all forms :test #'eq)
 			 (member '$functions forms :test #'eq))
 		     (setq forms (mapcar #'caar (cdr $functions)))))
@@ -122,7 +124,7 @@
 			      (when $compgrind
 				(mformat transl-file "~2%;; Function ~:@M~%" item))
 			      (print* t-item))))))
-          (to-macsyma-namestring out-file-name))
+          (pathname out-file-name))
 	 ;; unwind-protected
 	 (if transl-file (close transl-file))
 	 (if t-error (delete-file transl-file))))))
@@ -136,11 +138,6 @@
 (defvar tr-defaultf nil
   "A default only for the case of no arguments to $translate_file")
 
-;;; Temporary hack during debugging of this  code.
-
-(defun mergef (x y)
-  (merge-pathnames y x))
-
 (defun $compile_file (input-file &optional bin-file translation-output-file &aux result)
   (setq input-file (maxima-string input-file))
   (and bin-file(setq  bin-file (maxima-string bin-file)))
@@ -150,7 +147,7 @@
 	 (setq result (list '(mlist) input-file)))
 	(t (setq result (translate-file input-file translation-output-file))
 	   (setq input-file (third result))))
-  #+(or cmu scl sbcl clisp allegro openmcl)
+  #+(or cmu scl sbcl clisp allegro openmcl lispworks ecl)
   (multiple-value-bind (output-truename warnings-p failure-p)
       (if bin-file
 	  (compile-file input-file :output-file bin-file)
@@ -160,14 +157,12 @@
     ;; indicate that we found errors. Is this what we want?
     (unless failure-p
       (setq bin-file output-truename)))
-  #-(or cmu scl sbcl clisp allegro openmcl)
+  #-(or cmu scl sbcl clisp allegro openmcl lispworks ecl)
   (setq bin-file (compile-file input-file :output-file bin-file))
   (append result (list bin-file)))
 
-;; Converts a Maxima "string" (which is really a symbol that starts
-;; with the character '&') to a Lisp string.
 (defun maxima-string (symb)
-  (string-left-trim "&" (print-invert-case symb)))
+  (print-invert-case symb))
 
 (defmfun $translate_file (input-file &optional output-file)
   (setq input-file (maxima-string input-file))
